@@ -6,14 +6,12 @@ use strict;
 use 5.010000;
 
 use Exporter qw( import );
-our @EXPORT_OK = qw( choose_videos );
+our @EXPORT_OK = qw( choose_videos set_sort_videolist );
 
 use List::MoreUtils        qw( any none );
 use Term::Choose           qw( choose );
 use Term::ReadLine::Simple qw();
 
-use App::YTDL::Options qw( sort_order_list );
-
 
 
 sub _my_sort {
@@ -23,10 +21,10 @@ sub _my_sort {
                 ? ( $h_ref->{$a}{$item}, $h_ref->{$b}{$item} )
                 : ( $h_ref->{$b}{$item}, $h_ref->{$a}{$item} );
     if ( $item eq 'view_count_raw' ) {
-       ( $s[0] //  0 ) <=> ( $s[1] //  0 ) || ( $h_ref->{$a}{title} // '' ) cmp ( $h_ref->{$b}{title} // '' );
+       $s[0] <=> $s[1] || $h_ref->{$a}{title} cmp $h_ref->{$b}{title};
     }
     else {
-       ( $s[0] // '' ) cmp ( $s[1] // '' ) || ( $h_ref->{$a}{title} // '' ) cmp ( $h_ref->{$b}{title} // '' );
+       $s[0] cmp $s[1] || $h_ref->{$a}{title} cmp $h_ref->{$b}{title};
    }
 }
 
@@ -117,7 +115,7 @@ sub choose_videos {
             next FILTER;
         }
         elsif ( $choice eq $sort ) {
-            sort_order_list( $opt );
+            set_sort_videolist( $opt );
         }
         else {
             if ( $choice eq $enter ) {
@@ -149,6 +147,57 @@ sub choose_videos {
 }
 
 
+sub set_sort_videolist {
+    my ( $opt ) = @_;
+    my $backup_item  = $opt->{list_sort_item};
+    my $backup_order = $opt->{list_sort_order};
+    my $sort_items = [ 'upload_date', 'title', 'view_count_raw', 'duration' ];
+    my $confirm = '  CONFIRM';
+    my @pre = ( undef, $confirm );
+    my $choices = [ @pre, map { my $s = ucfirst; $s =~ s/_raw\z//; $s =~ s/_/ /g; '- ' . $s } @$sort_items ];
+
+    while ( 1 ) {
+        my $current = ucfirst $opt->{list_sort_item};
+        $current =~ s/_raw\z//;
+        $current =~ s/_/ /g;
+        my $prompt = sprintf 'Sort item: [%s]', $current;
+        my $idx = choose (
+            $choices,
+            { prompt => $prompt, clear_screen => 0, layout => 3, index => 1, undef => '  BACK' }
+        );
+        if ( ! defined $idx || ! defined $choices->[$idx] ) {
+            $opt->{list_sort_item} = $backup_item;
+            return;
+        }
+        if ( $choices->[$idx] eq $confirm ) {
+            last;
+        }
+        $idx -= @pre;
+        $opt->{list_sort_item} = $sort_items->[$idx];
+    }
+
+    while ( 1 ) {
+        my $curr_sort_item = ucfirst $opt->{list_sort_item};
+        $curr_sort_item =~ s/_raw\z//;
+        $curr_sort_item =~ s/_/ /g;
+        my $order_prompt = sprintf 'Sort order "%s": [%s]', $curr_sort_item, $opt->{list_sort_order};
+        my $choice = choose (
+            [ @pre, '- Asc', '- Desc' ],
+            { prompt => $order_prompt, clear_screen => 0, layout => 3, undef => '  BACK' }
+        );
+        if ( ! defined $choice ) {
+            $opt->{list_sort_order} = $backup_order;
+            return;
+        }
+        if ( $choice eq $confirm ) {
+            $opt->{change}++;
+            return;
+        }
+        $choice =~ s/^-\s//;
+        $opt->{list_sort_order} = $choice;
+    }
+}
+
 
 1;
 
