@@ -20,8 +20,8 @@ use Try::Tiny          qw( try catch );
 
 use if $^O eq 'MSWin32', 'Win32::Console::ANSI';
 
-use App::YTDL::Data   qw( get_new_video_url );
-use App::YTDL::Helper qw( sec_to_time encode_fs encode_stdout timestamp_to_upload_date HIDE_CURSOR SHOW_CURSOR );
+use App::YTDL::Get_Data qw( get_new_video_url );
+use App::YTDL::Helper   qw( sec_to_time encode_fs encode_stdout timestamp_to_upload_date HIDE_CURSOR SHOW_CURSOR );
 
 END { print SHOW_CURSOR }
 
