@@ -120,7 +120,9 @@ sub write_json {
 
 sub read_json {
     my ( $file ) = @_;
-    return {} if ! -f encode_fs( $file );
+    if ( ! -f encode_fs( $file ) ) {
+        return {};
+    }
     open my $fh, '<', encode_fs( $file ) or die $!;
     my $json = do { local $/; <$fh> };
     close $fh;
