@@ -8,6 +8,7 @@ use 5.010000;
 use Exporter qw( import );
 our @EXPORT_OK = qw( get_download_infos );
 
+use File::Path            qw( make_path );
 use File::Spec::Functions qw( catfile catdir );
 
 use Term::ANSIScreen   qw( :cursor :screen );
@@ -111,13 +112,13 @@ sub get_download_infos {
             if ( $opt->{extractor_dir} ) {
                 my $extractor_dir = sanitize_for_path( $ex );
                 $video_dir = catdir $video_dir, $extractor_dir;
-                mkdir encode_fs( $video_dir ) or die $! if ! -d encode_fs( $video_dir );
+                make_path encode_fs( $video_dir );
             }
             if ( $opt->{channel_dir} == 2 || $opt->{channel_dir} == 1 && $info->{$ex}{$video_id}{from_list} ) {
                 if ( length $info->{$ex}{$video_id}{uploader} ) {
                     my $channel_name = sanitize_for_path( $info->{$ex}{$video_id}{uploader} );
                     $video_dir = catdir $video_dir, $channel_name;
-                    mkdir encode_fs( $video_dir ) or die $! if ! -d encode_fs( $video_dir );
+                    make_path encode_fs( $video_dir );
                 }
             }
             $info->{$ex}{$video_id}{video_dir} = $video_dir;
