@@ -16,7 +16,7 @@ use Text::LineFold     qw();
 
 use if $^O eq 'MSWin32', 'Win32::Console::ANSI';
 
-use App::YTDL::Data         qw( get_download_info_as_json );
+use App::YTDL::Get_Data     qw( get_download_info_as_json );
 use App::YTDL::Data_Extract qw( json_to_hash );
 
 
