@@ -9,6 +9,7 @@ use Exporter qw( import );
 our @EXPORT_OK = qw( search_and_merge );
 
 use File::Copy            qw( move );
+use File::Path            qw( make_path );
 use File::Spec::Functions qw( catfile catdir );
 use Time::Local           qw( timelocal );
 
@@ -80,9 +81,7 @@ sub search_and_merge {
                     push @merged, $out;
                     if ( $opt->{merged_in_files} == 1 ) {
                         my $dir_orig_files = catdir $video_dir, $opt->{dir_stream_files};
-                        if ( ! -d $dir_orig_files ) {
-                            mkdir $dir_orig_files or die $!;
-                        }
+                        make_path $dir_orig_files;
                         move $video, $dir_orig_files or die $!;
                         move $audio, $dir_orig_files or die $!;
                     }
